Support — boto v2.27.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »

# Support

## boto.support

`boto.support.` `connect_to_region`(region_name, **kw_params)

`boto.support.` `regions`()

  Get all available regions for the Amazon Support service.

  Return type: | list
  Returns: | A list of `boto.regioninfo.RegionInfo`

## boto.support.layer1

class `boto.support.layer1.` `SupportConnection`(**kwargs)

  AWS Support The AWS Support API reference is intended for programmers who need detailed information about the AWS Support actions and data types. This service enables you to manage your AWS Support cases programmatically. It uses HTTP methods that return results in JSON format.

  The AWS Support service also exposes a set of `Trusted Advisor`_ features. You can retrieve a list of checks and their descriptions, get check results, specify checks to refresh, and get the refresh status of checks.

  The following list describes the AWS Support case management actions:

  - **Service names, issue categories, and available severity levels. **The actions DescribeServices and DescribeSeverityLevels enable you to obtain AWS service names, service codes, service categories, and problem severity levels. You use these values when you call the CreateCase action.
  - Case creation, case details, and case resolution. The actions CreateCase, DescribeCases, and ResolveCase enable you to create AWS Support cases, retrieve them, and resolve them.
  - Case communication. The actions DescribeCommunications and AddCommunicationToCase enable you to retrieve and add communication to AWS Support cases.

  The following list describes the actions available from the AWS Support service for Trusted Advisor:

  - DescribeTrustedAdvisorChecks returns the list of checks that run against your AWS resources.
  - Using the CheckId for a specific check returned by DescribeTrustedAdvisorChecks, you can call DescribeTrustedAdvisorCheckResult to obtain the results for the check you specified.
  - DescribeTrustedAdvisorCheckSummaries returns summarized results for one or more Trusted Advisor checks.
  - RefreshTrustedAdvisorCheck requests that Trusted Advisor rerun a specified check.
  - DescribeTrustedAdvisorCheckRefreshStatuses reports the refresh status of one or more checks.

  For authentication of requests, AWS Support uses `Signature Version 4 Signing Process`_.

  See the AWS Support `User Guide`_ for information about how to use this service to create and manage your support cases, and how to call Trusted Advisor for results of checks on your resources.

  `APIVersion` = '2013-04-15'
  `DefaultRegionEndpoint` = 'support.us-east-1.amazonaws.com'
  `DefaultRegionName` = 'us-east-1'
  `ResponseError`

    alias of `JSONResponseError`

  `ServiceName` = 'Support'
  `TargetPrefix` = 'AWSSupport_20130415'
  `add_communication_to_case`(communication_body, case_id=None, cc_email_addresses=None)

    Adds additional customer communication to an AWS Support case. You use the CaseId value to identify the case to add communication to. You can list a set of email addresses to copy on the communication using the CcEmailAddresses value. The CommunicationBody value contains the text of the communication.

    The response indicates the success or failure of the request.

    This operation implements a subset of the behavior on the AWS Support `Your Support Cases`_ web form.

    Parameters: | case_id (string) – The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case- 12345678910-2013-c4c1d2bf33c5cf47 communication_body (string) – The body of an email communication to add to the support case. cc_email_addresses (list) – The email addresses in the CC line of an email to be added to the support case.

  `create_case`(subject, communication_body, service_code=None, severity_code=None, category_code=None, cc_email_addresses=None, language=None, issue_type=None)

    Creates a new case in the AWS Support Center. This operation is modeled on the behavior of the AWS Support Center `Open a new case`_ page. Its parameters require you to specify the following information:

    1. ServiceCode. The code for an AWS service. You obtain the ServiceCode by calling DescribeServices.
    2. CategoryCode. The category for the service defined for the ServiceCode value. You also obtain the category code for a service by calling DescribeServices. Each AWS service defines its own set of category codes.
    3. SeverityCode. A value that indicates the urgency of the case, which in turn determines the response time according to your service level agreement with AWS Support. You obtain the SeverityCode by calling DescribeSeverityLevels.
    4. Subject. The Subject field on the AWS Support Center `Open a new case`_ page.
    5. CommunicationBody. The Description field on the AWS Support Center `Open a new case`_ page.
    6. Language. The human language in which AWS Support handles the case. English and Japanese are currently supported.
    7. CcEmailAddresses. The AWS Support Center CC field on the `Open a new case`_ page. You can list email addresses to be copied on any correspondence about the case. The account that opens the case is already identified by passing the AWS Credentials in the HTTP POST method or in a method or function call from one of the programming languages supported by an `AWS SDK`_.
    8. IssueType. The type of issue for the case. You can specify either “customer-service” or “technical.” If you do not indicate a value, the default is “technical.”

    The AWS Support API does not currently support the ability to add attachments to cases. You can, however, call AddCommunicationToCase to add information to an open case.

    A successful CreateCase request returns an AWS Support case number. Case numbers are used by the DescribeCases action to retrieve existing AWS Support cases.

    Parameters: | subject (string) – The title of the AWS Support case. service_code (string) – The code for the AWS service returned by the call to DescribeServices. severity_code (string) –

    The code for the severity level returned by the call to
      DescribeSeverityLevels.
    The availability of severity levels depends on each customer’s support
      subscription. In other words, your subscription may not necessarily require the urgent level of response time.

    Parameters: | category_code (string) – The category of problem for the AWS Support case. communication_body (string) – The communication body text when you create an AWS Support case by calling CreateCase. cc_email_addresses (list) – A list of email addresses that AWS Support copies on case correspondence. language (string) – The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English (“en”) and Japanese (“ja”). Language parameters must be passed explicitly for operations that take them. issue_type (string) – The type of issue for the case. You can specify either “customer-service” or “technical.” If you do not indicate a value, the default is “technical.”

  `describe_cases`(case_id_list=None, display_id=None, after_time=None, before_time=None, include_resolved_cases=None, next_token=None, max_results=None, language=None)

    Returns a list of cases that you specify by passing one or more case IDs. In addition, you can filter the cases by date by setting values for the AfterTime and BeforeTime request parameters.

    The response returns the following in JSON format:

    1. One or more CaseDetails data types.
    2. One or more NextToken values, which specify where to paginate the returned records represented by the CaseDetails objects.

    Parameters: | case_id_list (list) – A list of ID numbers of the support cases you want returned. The maximum number of cases is 100. display_id (string) – The ID displayed for a case in the AWS Support Center user interface. after_time (string) – The start date for a filtered date search on support case communications. before_time (string) – The end date for a filtered date search on support case communications. include_resolved_cases (boolean) – Specifies whether resolved support cases should be included in the DescribeCases results. next_token (string) – A resumption point for pagination. max_results (integer) – The maximum number of results to return before paginating. language (string) – The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English (“en”) and Japanese (“ja”). Language parameters must be passed explicitly for operations that take them.

  `describe_communications`(case_id, before_time=None, after_time=None, next_token=None, max_results=None)

    Returns communications regarding the support case. You can use the AfterTime and BeforeTime parameters to filter by date. The CaseId parameter enables you to identify a specific case by its CaseId value.

    The MaxResults and NextToken parameters enable you to control the pagination of the result set. Set MaxResults to the number of cases you want displayed on each page, and use NextToken to specify the resumption of pagination.

    Parameters: | case_id (string) – The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case- 12345678910-2013-c4c1d2bf33c5cf47 before_time (string) – The end date for a filtered date search on support case communications. after_time (string) – The start date for a filtered date search on support case communications. next_token (string) – A resumption point for pagination. max_results (integer) – The maximum number of results to return before paginating.

  `describe_services`(service_code_list=None, language=None)

    Returns the current list of AWS services and a list of service categories that applies to each one. You then use service names and categories in your CreateCase requests. Each AWS service has its own set of categories.

    The service codes and category codes correspond to the values that are displayed in the Service and Category drop- down lists on the AWS Support Center `Open a new case`_ page. The values in those fields, however, do not necessarily match the service codes and categories returned by the DescribeServices request. Always use the service codes and categories obtained programmatically. This practice ensures that you always have the most recent set of service and category codes.

    Parameters: | service_code_list (list) – A JSON-formatted list of service codes available for AWS services. language (string) – The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English (“en”) and Japanese (“ja”). Language parameters must be passed explicitly for operations that take them.

  `describe_severity_levels`(language=None)

    Returns the list of severity levels that you can assign to an AWS Support case. The severity level for a case is also a field in the CaseDetails data type included in any CreateCase request.

    Parameters: | language (string) – The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English (“en”) and Japanese (“ja”). Language parameters must be passed explicitly for operations that take them.

  `describe_trusted_advisor_check_refresh_statuses`(check_ids)

    Returns the refresh status of the Trusted Advisor checks that have the specified check IDs. Check IDs can be obtained by calling DescribeTrustedAdvisorChecks.

    Parameters: | check_ids (list) – The IDs of the Trusted Advisor checks.

  `describe_trusted_advisor_check_result`(check_id, language=None)

    Returns the results of the Trusted Advisor check that has the specified check ID. Check IDs can be obtained by calling DescribeTrustedAdvisorChecks.

    The response contains a TrustedAdvisorCheckResult object, which contains these three objects:

    - TrustedAdvisorCategorySpecificSummary
    - TrustedAdvisorResourceDetail
    - TrustedAdvisorResourcesSummary

    In addition, the response contains these fields:

    - Status. The alert status of the check: “ok” (green), “warning” (yellow), “error” (red), or “not_available”.
    - Timestamp. The time of the last refresh of the check.
    - CheckId. The unique identifier for the check.

    Parameters: | check_id (string) – The unique identifier for the Trusted Advisor check. language (string) – The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English (“en”) and Japanese (“ja”). Language parameters must be passed explicitly for operations that take them.

  `describe_trusted_advisor_check_summaries`(check_ids)

    Returns the summaries of the results of the Trusted Advisor checks that have the specified check IDs. Check IDs can be obtained by calling DescribeTrustedAdvisorChecks.

    The response contains an array of TrustedAdvisorCheckSummary objects.

    Parameters: | check_ids (list) – The IDs of the Trusted Advisor checks.

  `describe_trusted_advisor_checks`(language)

    Returns information about all available Trusted Advisor checks, including name, ID, category, description, and metadata. You must specify a language code; English (“en”) and Japanese (“ja”) are currently supported. The response contains a TrustedAdvisorCheckDescription for each check.

    Parameters: | language (string) – The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English (“en”) and Japanese (“ja”). Language parameters must be passed explicitly for operations that take them.

  `make_request`(action, body)
  `refresh_trusted_advisor_check`(check_id)

    Requests a refresh of the Trusted Advisor check that has the specified check ID. Check IDs can be obtained by calling DescribeTrustedAdvisorChecks.

    The response contains a RefreshTrustedAdvisorCheckResult object, which contains these fields:

    - Status. The refresh status of the check: “none”, “enqueued”, “processing”, “success”, or “abandoned”.
    - MillisUntilNextRefreshable. The amount of time, in milliseconds, until the check is eligible for refresh.
    - CheckId. The unique identifier for the check.

    Parameters: | check_id (string) – The unique identifier for the Trusted Advisor check.

  `resolve_case`(case_id=None)

    Takes a CaseId and returns the initial state of the case along with the state of the case after the call to ResolveCase completed.

    Parameters: | case_id (string) – The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case- 12345678910-2013-c4c1d2bf33c5cf47

## boto.support.exceptions

exception `boto.support.exceptions.` `CaseCreationLimitExceeded`(status, reason, body=None, *args)

exception `boto.support.exceptions.` `CaseIdNotFound`(status, reason, body=None, *args)

exception `boto.support.exceptions.` `InternalServerError`(status, reason, body=None, *args)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »